==> haskell-glib-0.13.2.2-2-armv7h.pkg.tar.xz: usr/share/haskell/gtk2hs-glib/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: glib
version: 0.13.2.2
id: glib-0.13.2.2-af22ca5ff15cdc3e58e6f0b0228d4cfc
key: glib_I50VnAx0lsAGkf2HUGy7ut
license: LGPL-2.1
copyright: (c) 2001-2010 The Gtk2Hs Team
maintainer: gtk2hs-users@lists.sourceforge.net
stability: stable
homepage: http://projects.haskell.org/gtk2hs/
synopsis: Binding to the GLIB library for Gtk2Hs.
description:
    GLib is a collection of C data structures and utility functions
    for the GObject system, main loop implementation, for strings and
    common data structures dealing with Unicode. This package only binds
    as much functionality as required to support the packages that
    wrap libraries that are themselves based on GLib.
category: System
author: Axel Simon, Duncan Coutts
exposed: True
exposed-modules:
    System.Glib System.Glib.GError System.Glib.Properties
    System.Glib.Attributes System.Glib.Signals System.Glib.MainLoop
    System.Glib.GDateTime System.Glib.GObject System.Glib.Utils
    System.Glib.StoreValue System.Glib.FFI System.Glib.Flags
    System.Glib.UTFString System.Glib.Types System.Glib.GList
    System.Glib.GString System.Glib.GType System.Glib.GTypeConstants
    System.Glib.GValue System.Glib.GValueTypes System.Glib.GParameter
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/glib-0.13.2.2
library-dirs: /usr/lib/ghc-7.10.3/site-local/glib-0.13.2.2
data-dir: /usr/share/arm-linux-ghc-7.10.3/glib-0.13.2.2
hs-libraries: HSglib-0.13.2.2-I50VnAx0lsAGkf2HUGy7ut
extra-libraries:
    gobject-2.0 glib-2.0
include-dirs: /usr/include/glib-2.0 /usr/lib/glib-2.0/include
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
    utf8-string-1.0.1.1-55be01444fdc59e978af349d80596373
haddock-interfaces: /usr/share/doc/haskell-glib/html/glib.haddock
haddock-html: /usr/share/doc/haskell-glib/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-glib-0.13.2.2-3-armv7h.pkg.tar.xz: usr/share/haskell/gtk2hs-glib/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: glib
version: 0.13.2.2
id: glib-0.13.2.2-dee78e2394fbb4564d664049b5900c2d
key: glib_1k0TiRm3S3u0RjZ08MH1od
license: LGPL-2.1
copyright: (c) 2001-2010 The Gtk2Hs Team
maintainer: gtk2hs-users@lists.sourceforge.net
stability: stable
homepage: http://projects.haskell.org/gtk2hs/
synopsis: Binding to the GLIB library for Gtk2Hs.
description:
    GLib is a collection of C data structures and utility functions
    for the GObject system, main loop implementation, for strings and
    common data structures dealing with Unicode. This package only binds
    as much functionality as required to support the packages that
    wrap libraries that are themselves based on GLib.
category: System
author: Axel Simon, Duncan Coutts
exposed: True
exposed-modules:
    System.Glib System.Glib.GError System.Glib.Properties
    System.Glib.Attributes System.Glib.Signals System.Glib.MainLoop
    System.Glib.GDateTime System.Glib.GObject System.Glib.Utils
    System.Glib.StoreValue System.Glib.FFI System.Glib.Flags
    System.Glib.UTFString System.Glib.Types System.Glib.GList
    System.Glib.GString System.Glib.GType System.Glib.GTypeConstants
    System.Glib.GValue System.Glib.GValueTypes System.Glib.GParameter
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/glib-0.13.2.2
library-dirs: /usr/lib/ghc-7.10.3/site-local/glib-0.13.2.2
data-dir: /usr/share/arm-linux-ghc-7.10.3/glib-0.13.2.2
hs-libraries: HSglib-0.13.2.2-1k0TiRm3S3u0RjZ08MH1od
extra-libraries:
    gobject-2.0 glib-2.0
include-dirs: /usr/include/glib-2.0 /usr/lib/glib-2.0/include
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
    utf8-string-1.0.1.1-55be01444fdc59e978af349d80596373
haddock-interfaces: /usr/share/doc/haskell-glib/html/glib.haddock
haddock-html: /usr/share/doc/haskell-glib/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
